@@ -16,6 +16,7 @@
 
 import logging
 
+from django.conf import settings
 from django.core import urlresolvers
 from django.core.urlresolvers import reverse_lazy
 from django import template
@@ -160,7 +161,8 @@ class GraphMetric(tables.LinkAction):
         endpoint = str(reverse_lazy(ov_constants.URL_PREFIX + 'proxy'))
         endpoint = self.table.request.build_absolute_uri(endpoint)
         self.attrs['target'] = '_blank'
-        url = '/static/grafana/index.html#/dashboard/script/detail.js'
+        url = (settings.STATIC_URL or '') + \
+            'grafana/index.html#/dashboard/script/detail.js'
         query = "?name=%s&threshold=%s&api=%s" % \
                 (name, threshold, endpoint)
         return url + query
@@ -192,12 +194,21 @@ class DeleteAlarm(tables.DeleteAction):
         api.monitor.alarm_delete(request, obj_id)
 
 
-class AlarmsFilterAction(tables.FilterAction):
-    def filter(self, table, alarms, filter_string):
-        """Naive case-insensitive search."""
-        q = filter_string.lower()
-        return [alarm for alarm in alarms
-                if q in alarm['metrics'][0]['name'].lower()]
+class AlarmsFilterAction(tables.LinkAction):
+    name = "filter"
+    verbose_name = _("Filter Alarms")
+    classes = ("ajax-modal",)
+    icon = "plus"
+    policy_rules = (("alarm", "alarm:filter"),)
+    ajax = True
+
+
+    def get_link_url(self):
+        return urlresolvers.reverse(constants.URL_PREFIX + 'alarm_filter',
+                                    args=())
+
+    def allowed(self, request, datum=None):
+        return True
 
 
 class AlarmsTable(tables.DataTable):
@@ -236,7 +247,8 @@ def show_timestamp(data):
 
 class AlarmHistoryTable(tables.DataTable):
     timestamp = tables.Column(transform=show_timestamp,
-                              verbose_name=_('Timestamp'))
+                              verbose_name=_('Timestamp'),
+                              attrs={"data-type": "timestamp"})
     old_state = tables.Column('old_state', verbose_name=_('Old State'))
     new_state = tables.Column('new_state', verbose_name=_('New State'))
     alarmDimensions = tables.Column(transform=show_metric_dimensions,
