@@ -14,9 +14,10 @@
 
 import logging
 
-from django.conf import settings  # noqa
 from monascaclient import client as monasca_client
 from openstack_dashboard.api import base
+from monitoring.config import local_settings as settings
+
 
 LOG = logging.getLogger(__name__)
 
@@ -30,8 +31,7 @@ def format_parameters(params):
 
 
 def monasca_endpoint(request):
-    service_type = getattr(settings, 'MONITORING_SERVICE_TYPE', 'monitoring')
-    endpoint = base.url_for(request, service_type)
+    endpoint = base.url_for(request, settings.MONITORING_SERVICE_TYPE)
     if endpoint.endswith('/'):
         endpoint = endpoint[:-1]
     return endpoint
@@ -39,15 +39,13 @@ def monasca_endpoint(request):
 
 def monascaclient(request, password=None):
     api_version = "2_0"
-    insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
-    cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
     endpoint = monasca_endpoint(request)
     LOG.debug('monascaclient connection created using token "%s" , url "%s"' %
               (request.user.token.id, endpoint))
     kwargs = {
         'token': request.user.token.id,
-        'insecure': insecure,
-        'ca_file': cacert,
+        'insecure': settings.OPENSTACK_SSL_NO_VERIFY,
+        'ca_file': settings.OPENSTACK_SSL_CACERT,
         'username': request.user.username,
         'password': password
         # 'timeout': args.timeout,
@@ -65,15 +63,33 @@ def alarm_list(request, offset=0, limit=10000, marker=None, paginate=False):
     return result['elements'] if type(result) is dict else result
 
 
-def alarm_list_by_service(request, service_name,  offset=0, limit=10000,
+def alarm_list_by_dimension(request, dimensions, offset=0, limit=10000,
                           marker=None, paginate=False):
-    name, value = service_name.split('=')
-    service_dim = {name: value}
-    result = monascaclient(request).alarms.list(offset=offset, limit=limit,
-                                                metric_dimensions=service_dim)
+    dim_dict = {}
+    metric = None
+    dimensions = dimensions.replace(" ", "")
+    dimensions = dimensions.split(",")
+    for item in dimensions:
+        name, value = item.split("=")
+        if name == 'metric':
+            metric = value
+        else:
+            dim_dict[name] = value
+    if metric:
+        result = monascaclient(request).alarms.list(offset=offset, limit=limit,
+                                                metric_dimensions=dim_dict,
+                                                metric_name=metric)
+    else:
+        result = monascaclient(request).alarms.list(offset=offset, limit=limit,
+                                                metric_dimensions=dim_dict)
     return result['elements'] if type(result) is dict else result
 
 
+def alarm_show(request, alarm_id):
+    result = monascaclient(request).alarms.get(alarm_id=alarm_id)
+    return result
+
+
 def alarm_delete(request, alarm_id):
     return monascaclient(request).alarms.delete(alarm_id=alarm_id)
 
